'''
 * Copyright (c) 2024-2025 National Fundamental Software of China Co., Ltd.
 * 
 * You should have find a copy of NFSChina License. If not, please contact us 
 * by email <os_support@nfschina.com>  
 * 
'''

'''
获取安装信息
包含以下信息：
1、软件包安装列表
2、系统开始安装时间
3、系统结束安装时间
4、系统安装耗时
5、系统安装版本
'''
import subprocess
import os
from datetime import datetime, timedelta
from pyanaconda.core.configuration.anaconda import conf


'''
获取安装信息
1、软件包安装列表
'''
def get_rpm_list(path):
    res = ''
    try:
        file_path = os.path.join(path)
        rpms = subprocess.run(
            'chroot %s rpm -qa' % file_path,
            stdout=subprocess.PIPE,
            encoding="utf-8",
            timeout=10000, shell=True)
        for rpm in rpms.stdout.split('\n'):
            if rpm is not None and rpm != '':
                res += rpm + '\n'
    except Exception as e:
        print('get_install_info-->get_rpm_list--> ', e)
    return res


'''
获取安装信息
1、系统安装版本
'''
def get_os_version(path):
    res = ''
    try:
        file_path = os.path.join(path,'etc/nfs-release')
        with open(file_path, "r") as file:
            res = 'Os Version : '+file.read()
    except Exception as e:
        print('get_install_info-->get_rpm_list--> ', e)
    return res

'''
获取安装信息
1、系统开始安装时间
2、系统结束安装时间
3、系统安装耗时
'''
def get_install_time_info():
    res = ''
    try:
        file_path = os.path.join('/tmp/anaconda.log')
        start_time_str = subprocess.run(
            # 'chroot /mnt/sysroot/ rpm -qa',
            'grep "DBG ui.common: Left hub: SummaryHub" %s' % file_path,
            stdout=subprocess.PIPE,
            encoding="utf-8",
            timeout=10000, shell=True)
        start_time_tmp = start_time_str.stdout.split('\n')[0][0:8]
        end_time_str = subprocess.run(
            # 'chroot /mnt/sysroot/ rpm -qa',
            'sed -n \'$p\' %s' % file_path,
            stdout=subprocess.PIPE,
            encoding="utf-8",
            timeout=10000, shell=True)
        end_time_str_tmp = end_time_str.stdout.split('\n')[0][0:8]
        today = datetime.now()
        ftoday = today.strftime("%Y-%m-%d")
        start_time = datetime.strptime(ftoday+' '+start_time_tmp,'%Y-%m-%d %H:%M:%S')
        end_time = datetime.strptime(ftoday+' '+end_time_str_tmp,'%Y-%m-%d %H:%M:%S')
        if end_time < start_time :
            yesterday = today - timedelta(days=1)
            fyesterday = yesterday.strftime("%Y-%m-%d")
            end_time = datetime.strptime(fyesterday + ' ' + end_time_str_tmp, '%Y-%m-%d %H:%M:%S')
        time_difference = end_time - start_time
        total_seconds = time_difference.total_seconds()
        res = '#System installation performance\nSystem installation start time=' + start_time.strftime('%Y-%m-%d %H:%M:%S') +'\nSystem installation end time='+ end_time.strftime('%Y-%m-%d %H:%M:%S')  +'\nTime taken for system installation='+ str(int(total_seconds // 60))+'m'+str(int(total_seconds % 60))+'s'

    except Exception as e:
        print('get_install_info-->get_install_info--> ', e)
    return res

'''
获取安装信息
'''
def get_install_info():
    return '\n'+ get_os_version(conf.target.system_root) + '\n' + get_install_time_info()+'\n\n#Install package list\n'+get_rpm_list(conf.target.system_root)

